@@ -48,7 +48,7 @@ class TestViews(BaseTestCase):
         featured_pages = self.views.get_featured_pages(limit=10)
         self.assertEqual(
             ['Test Page 9', 'Test Page 8'],
-            [p['title'] for p in featured_pages])
+            [p.title for p in featured_pages])
 
     def test_get_pages_count(self):
         self.repo.create_pages(count=10)
@@ -59,7 +59,7 @@ class TestViews(BaseTestCase):
         self.repo.create_pages(count=10)
         pages = self.views.get_pages(limit=2, order_by=('title',))
         self.assertEqual(
-            [p['title'] for p in pages],
+            [p.title for p in pages],
             ['Test Page 0', 'Test Page 1'])
 
     def test_get_pages_reversed(self):
@@ -69,7 +69,7 @@ class TestViews(BaseTestCase):
                 arrow.utcnow() - timedelta(days=i)).isoformat())
         pages = self.views.get_pages(limit=2, reverse=True)
         self.assertEqual(
-            [p['title'] for p in pages],
+            [p.title for p in pages],
             ['Test Page 0', 'Test Page 1'])
 
     def test_get_available_languages(self):
@@ -93,10 +93,10 @@ class TestViews(BaseTestCase):
 
         page1, page2 = self.views.get_featured_category_pages(category1.uuid)
         self.assertEqual(
-            set([page1['title'], page2['title']]),
+            set([page1.title, page2.title]),
             set(['Test Page 8', 'Test Page 9']))
         self.assertEqual(
-            set([page1['language'], page2['language']]),
+            set([page1.language, page2.language]),
             set(['eng_UK', 'eng_UK']))
         self.assertEqual(
             [], self.views.get_featured_category_pages(category2.uuid))
@@ -137,20 +137,25 @@ class TestViews(BaseTestCase):
         # Assert swahili content
         page1, page2 = self.views.get_featured_category_pages(category3.uuid)
         self.assertEqual(
-            set([page1['language'], page2['language']]),
+            set([page1.language, page2.language]),
             set(['swh_KE', 'swh_KE']))
         self.assertEqual(
             [], self.views.get_featured_category_pages(category4.uuid))
 
     def test_get_page_by_slug(self):
-        self.repo.create_pages(count=10)
-        p = self.views.get_page(None, 'test-page-1')
-        self.assertEqual(p['title'], 'Test Page 1')
+        self.repo.create_pages(count=5)
+        self.repo.create_pages(count=5, locale='swh_KE')
+        p = self.views.get_page(None, 'test-page-1', 'eng_UK')
+        self.assertEqual(p.title, 'Test Page 1')
+        self.assertEqual(p.language, 'eng_UK')
+
+        p = self.views.get_page(None, 'test-page-1', 'swh_KE')
+        self.assertEqual(p.language, 'swh_KE')
 
         with self.assertRaises(exceptions.DoesNotExist):
             p = self.views.get_page(None, 'invalid-slug')
 
-    def test_markdown_rendering(self):
+    def test_content_markdown_rendering(self):
         [page] = self.repo.create_pages(count=1)
         page.content = '**strong**'
         page.description = '_emphasised_'
@@ -165,6 +170,21 @@ class TestViews(BaseTestCase):
         self.assertEqual(
             response['description'], '<p><em>emphasised</em></p>')
 
+    def test_flatpage_markdown_rendering(self):
+        [page] = self.repo.create_pages(count=1)
+        page.content = '**strong**'
+        page.description = '_emphasised_'
+        page.save(True, message='Add markdown markup')
+
+        request = testing.DummyRequest()
+        request.matchdict['slug'] = page.slug
+        self.views = CmsViews(request)
+        response = self.views.flatpage()
+        self.assertEqual(
+            response['content'], '<p><strong>strong</strong></p>')
+        self.assertEqual(
+            response['description'], '<p><em>emphasised</em></p>')
+
     def test_get_categories(self):
         category1, category2 = self.repo.create_categories()
         category3, category4 = self.repo.create_categories(
@@ -172,16 +192,30 @@ class TestViews(BaseTestCase):
 
         cat1, cat2 = self.views.get_categories()
         self.assertEqual(
-            set([cat1['language'], cat2['language']]),
+            set([cat1.language, cat2.language]),
             set(['eng_UK', 'eng_UK']))
 
         # Change language
         self.views = CmsViews(testing.DummyRequest({'_LOCALE_': 'swh_KE'}))
         cat1, cat2 = self.views.get_categories()
         self.assertEqual(
-            set([cat1['language'], cat2['language']]),
+            set([cat1.language, cat2.language]),
             set(['swh_KE', 'swh_KE']))
 
+    def test_get_category(self):
+        category, _ = self.repo.create_categories([u'dog', u'cat'], 'swh_KE')
+        [page] = self.repo.create_pages(count=1, locale='swh_KE')
+        page.primary_category = category
+        page.save(True, message="Adding category.")
+
+        request = testing.DummyRequest({'_LOCALE_': 'swh_KE'})
+        request.matchdict['category'] = category.uuid
+        views = CmsViews(request)
+        response = views.category()
+        self.assertEqual(response['category'].uuid, category.uuid)
+        self.assertEqual(
+            [p.uuid for p in response['pages']], [page.uuid])
+
     def test_get_top_nav(self):
         category1, category2 = self.repo.create_categories()
         category3, category4 = self.repo.create_categories(
@@ -193,5 +227,5 @@ class TestViews(BaseTestCase):
         self.views = CmsViews(testing.DummyRequest({'_LOCALE_': 'swh_KE'}))
         cat1, cat2 = self.views.get_top_nav
         self.assertEqual(
-            set([cat1['language'], cat2['language']]),
+            set([cat1.language, cat2.language]),
             set(['swh_KE', 'swh_KE']))
